@@ -956,8 +956,8 @@ These methods provide interfaces to alignment files in SAM/BAM/CRAM format.
 =item $hts_file = Bio::DB::HTSfile->open('/path/to/file.bam' [,$mode])
 
 Open the alignment file at the indicated path. Mode, if present, must be
-one of the file stream open flags ("r", "w", "a", "r+", etc.). If
-absent, mode defaults to "r". Currently writing is not supported.
+one of the file stream open flags ("r", "w", "wb", "wc", "a", "r+", etc.). If
+absent, mode defaults to "r". [write formats: w = SAM, wb = BAM, wc = CRAM]
 
 Note that Bio::DB::HTS objects are not stable across fork()
 operations. If you fork, and intend to use the object in both parent
@@ -979,12 +979,25 @@ Given an open alignment file, return a Bio::DB::HTS::Header object
 containing information about the reference sequence(s). Note that you
 must invoke header_read() at least once before calling read1().
 
+=item $status_code = $hfile->header_write($header, [$reference])
+
+Given a Bio::DB::HTSfile::Header object and a BAM file opened in write mode, write the
+header to the file. If the write fails the process will be terminated at the C layer.
+If $hfile is CRAM formated a second argument $reference, which is the path to the
+reference Fasta file, must be passed.
+The result code is (currently) always zero.
+
+
 =item $alignment = $hfile->read1($header)
 
 Read one alignment from the alignment file and return it as a
 Bio::DB::HTS::Alignment object. The $header parameter is returned by
 invoking header().
 
+=item $bytes = $hfile->write1($header, $alignment)
+
+Given a BAM file that has been opened in write mode and a Bio::DB::HTS::Alignment object,
+write the alignment to the BAM file and return the number of bytes successfully written.
 
 =back
 
@@ -1270,7 +1283,7 @@ Rishi Nag E<lt>rishi@ebi.ac.ukE<gt>
 =cut
 
 package Bio::DB::HTS;
-$Bio::DB::HTS::VERSION = '2.4';
+$Bio::DB::HTS::VERSION = '2.5';
 
 use strict;
 use warnings;
@@ -2069,7 +2082,7 @@ sub _glob_match {
 
 package Bio::DB::HTS::Fai;
 
-$Bio::DB::HTS::Fai::VERSION = '2.4';
+$Bio::DB::HTS::Fai::VERSION = '2.5';
 
 sub open { shift->load(@_) }
 
@@ -2086,7 +2099,7 @@ package Bio::SeqFeature::HTSCoverage;
 
 use base 'Bio::SeqFeature::Lite';
 
-$Bio::SeqFeature::HTSCoverage::VERSION = '2.4';
+$Bio::SeqFeature::HTSCoverage::VERSION = '2.5';
 
 sub coverage {
     my $self = shift;
@@ -2118,7 +2131,7 @@ sub gff3_string {
 
 package Bio::DB::HTSfile;
 
-$Bio::DB::HTS::HTSfile::VERSION = '2.4';
+$Bio::DB::HTS::HTSfile::VERSION = '2.5';
 
 use File::Spec;
 use Cwd;
